/* DChub - a Direct Connect text clone for Linux
 * Copyright (C) 2001 Eric Prevoteau
 *
 * hub_cluster.h: Copyright (C) Uriel Chemouni <uriel@adess.dyndns.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __HUB_CLUSTER_H__
#define __HUB_CLUSTER_H__

#include "hl_locks.h"
#include "cnx_lst.h"
#include "config.h"

typedef struct s_route_entry
{  
  int connected;
  int sock_fd;
  int load;
  HL_MUTEX entry_lock;          /* lock for *_commands */
  GList *incoming_commands;	/* glist of g_string, each one containing a string to send */
										/* g_string stored here are ALWAYS ended by a '|' */
  GString *in_partial;			/* partially received string */
  GList *outgoing_commands;	/* glist of g_string, each one containing a string to send */
  unsigned int ip;		/* user ip (added for in multi-server vertion)*/
}t_route_entry;

typedef struct s_route_table
{
  HL_MUTEX route_table_lock;
  CNX_ENTRY *table; /* allocate with sever_allocated_count * sizeof(t_route_entry)*/
  unsigned int server_count; /* number of server connected */
  unsigned int server_allocated_count; /* max number of server allow be se allocate structure*/
  unsigned int max_server_id; /* id of the last server */
}t_route_table;

extern t_route_table *route_table;

/*
 * create an empty route table
 *
 */

t_route_table *new_route_table(void);
int	parse_new_entry_from_hub(GString *inp, CNX_ENTRY *ptr);
int	parse_rem_entry_from_hub(GString *inp, CNX_ENTRY *ptr);
int	parse_pvm_from_hub(GString *inp, CNX_ENTRY *ptr);
int	parse_brd_from_hub(GString *inp, CNX_ENTRY *ptr);
int	parse_ban_from_hub(GString *inp, CNX_ENTRY *ptr);
int	parse_kik_from_hub(GString *inp, CNX_ENTRY *ptr);
int	interhub_cnx(char *hub_ip, int type);
int	parse_hub_from_hub(GString *inp, CNX_ENTRY *ent);
int	send_new_entry_to_hub(CNX_ENTRY* new_ent, CNX_ENTRY* dest, int overwrite);
int	lost_hub(CNX_ENTRY* ptr);
int	allocate_new_hub(CNX_ENTRY* ptr);
int	send_ban_entry_to_hub(CNX_ENTRY* ent, unsigned int duration);
int	send_kick_entry_to_hub(CNX_ENTRY* ent);

#endif
