/* DChub - a Direct Connect Hub for Linux
 * Copyright (C) 2001 Eric Prevoteau
 *
 * multi_private_chat.c: Copyright (C) Eric Prevoteau <www@ac2i.tzo.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __MULTI_PRIVATE_CHAT_H__
#define __MULTI_PRIVATE_CHAT_H__

/******************************************/
/* check if the given name is a chat_name */
/******************************************/
/* output: 1=yes, 0=no */
/***********************/
int is_a_mchat_name(const char *name);

/********************************/
/* create a new multi user chat */
/*************************************/
/* cmd syntax: "+new_mchat chatname" */
/******************************************************/
/* cmd == "+new_mchat "                               */
/* ptr is the user making the command                 */
/* dest_base="$To: remotenick From: Hub-Security $"   */
/* str=the full incoming string as it as been entered */
/* xtra_param= NULL                                   */
/* splitted_str= str splitted along " "               */
/******************************************************************************/
/* the function must return >=0 if the connection must remain alive (no error */
/* (0) or recoverable error (>0)) and a value <0 if there is a fatal error)   */
/******************************************************************************/ 
int create_multi_chat(const char *cmd, CNX_ENTRY *ptr,GString **dest_base, const GString *str, char *xtra_param, const GPtrArray *splitted_str);

/****************************************************************************/
/* this function is called when a user leaves the hub (on the "quit" event) */
/****************************************************************************/
/* evt_name="quit"            */
/* evt_emitter= user nickname */
/* nb_args= 0                 */
/* xtra_param=NULL            */
/******************************/
void leave_multi_chat(const char *evt_name, const char *evt_emitter, int nb_args, va_list ap, char *xtra_param);

/************************************************************************************/
/* this function is called when a user sends a private message (= "privchat" event) */
/************************************************************************************/
/* evt_name="privchat"                */
/* evt_emitter= user nickname         */
/* nb_args= 2                         */
/* ap={"dest_nick","message content"} */
/* xtra_param=NULL                    */ 
/**************************************/
void privchat_multi_chat(const char *evt_name, const char *evt_emitter, int nb_args, va_list ap, char *xtra_param);

/***************************************************************************************/
/* this function is called when a user retrieves the user list (= "getnicklist" event) */
/***************************************************************************************/
/* evt_name="getnicklist"             */
/* evt_emitter= user nickname         */
/* nb_args= 0                         */
/* xtra_param=NULL                    */
/**************************************/
void getnicklist_multi_chat(const char *evt_name, const char *evt_emitter, int nb_args, va_list ap, char *xtra_param);

/*******************************************************/
/* invite the given users to the given multi user chat */
/****************************************************************/
/* cmd syntax: "+invite_mchat chatname nickname [nickname ...]" */
/****************************************************************/
/* cmd == "+invite_mchat "                            */
/* ptr is the user making the command                 */
/* dest_base="$To: remotenick From: Hub-Security $"   */
/* str=the full incoming string as it as been entered */
/* xtra_param= NULL                                   */
/* splitted_str= str splitted along " "               */
/******************************************************************************/
/* the function must return >=0 if the connection must remain alive (no error */
/* (0) or recoverable error (>0)) and a value <0 if there is a fatal error)   */
/******************************************************************************/
int invite_multi_chat(const char *cmd, CNX_ENTRY *ptr,GString **dest_base, const GString *str, char *xtra_param, const GPtrArray *splitted_str);

/***********************************/
/* leave the given multi user chat */
/**************************************/
/* cmd syntax: "+leave_mchat chatname */
/******************************************************/
/* cmd == "+leave_mchat "                             */
/* ptr is the user making the command                 */
/* dest_base="$To: remotenick From: Hub-Security $"   */
/* str=the full incoming string as it as been entered */
/* xtra_param= NULL                                   */
/* splitted_str= str splitted along " "               */
/******************************************************************************/
/* the function must return >=0 if the connection must remain alive (no error */
/* (0) or recoverable error (>0)) and a value <0 if there is a fatal error)   */
/******************************************************************************/
int cmd_leave_multi_chat(const char *cmd, CNX_ENTRY *ptr,GString **dest_base, const GString *str, char *xtra_param, const GPtrArray *splitted_str);

#endif
