/* DChub - a Direct Connect Hub for Linux
 * Copyright (C) 2001 Eric Prevoteau
 *
 * toolkit.c: Copyright (C) Eric Prevoteau <www@ac2i.tzo.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#include "toolkit.h"

#if 0
/*************************************************************************/
/* this function splits the string (in_string) using the given separator */
/* Each part of the splitted string is appended to chunk. The address of */
/* the appended string is appended to the given tbl.                     */
/* if *tbl or *chunk ==NULL, it is created.                              */
/* multiple consecutive separators are ignored (like strtok).            */
/*************************************************************************/
void split_string_into_array(GPtrArray **tbl, GStringChunk **chunk, const char *in_string, char *separators)
{
	char *dp;
	char *ptr;
	char *cur;

	if(*tbl==NULL)
		*tbl=g_ptr_array_new();
	if(*chunk==NULL)
		*chunk=g_string_chunk_new(64);

	/* duplicate the initial string */
	dp=strdup(in_string);
	if(dp==NULL)
		return;

	/* and split the string */
	cur=strtok_r(dp,separators,&ptr);
	while(cur!=NULL)
	{
		gchar *added;

		added=g_string_chunk_insert((*chunk),cur);
		g_ptr_array_add((*tbl),added);

		cur=strtok_r(NULL,separators,&ptr);
	}

	free(dp);
}
#else
/*************************************************************************/
/* this function splits the string (in_string) using the given separator */
/* Each part of the splitted string is appended to chunk. The address of */
/* the appended string is appended to the given tbl.                     */
/* if *tbl or *chunk ==NULL, it is created.                              */
/* multiple consecutive separators are ignored (like strtok).            */
/*************************************************************************/
void split_string_into_array(GPtrArray **tbl, GStringChunk **chunk, const char *in_string, char *separators)
{
	char *dp;
	char *ptr;
	char *cur;

	if(*tbl==NULL)
		*tbl=g_ptr_array_new();
	if(*chunk==NULL)
		*chunk=g_string_chunk_new(64);

	/* duplicate the initial string */
	dp=strdup(in_string);
	if(dp==NULL)
		return;

	ptr=dp;

	/* and split the string */
	do
	{
		int quoted=0;

		cur=ptr;
		if(*cur=='"')
		{	/* the block is enclosed between quotes */
			cur++;
			ptr=strchr(cur,'"');
			quoted=1;
		}
		else
		{
			ptr=strchr(cur,' ');
		}

		if(ptr!=NULL)
		{
			*ptr++='\0';
		}
		
		/* the string must have a size not null or be quoted (an quoted empty string is valid) */
		if((strlen(cur))||quoted)
		{
			gchar *added;

			added=g_string_chunk_insert((*chunk),cur);
			g_ptr_array_add((*tbl),added);
		}
	}while(ptr!=NULL);
		
	free(dp);
}
#endif

/******************************************************************/
/* copy the source string into the dest string (upto max_byte-1). */
/* The dest string is always \0 terminated                        */
/******************************************************************/
void strncpy_max(char *destination, char *source, int max_byte)
{
	strncpy(destination,source,max_byte-1);
	destination[max_byte-1]='\0';
}

